Internals
=========

This section covers the developers-only documentation, i.e part of the API
that may be changed anytime by anyone.

.. toctree::
   :maxdepth: 2

   polys
   gruntz
   hyperexpand
   g-functions
   evalf
